@@ -1,6 +1,14 @@
-from dagster import Executor, Field, Noneable, Permissive, StringSource, check, executor
-from dagster.core.definitions.executor import check_cross_process_constraints
-from dagster.core.execution.retries import Retries, RetryMode, get_retries_config
+from dagster import (
+    Executor,
+    Field,
+    Noneable,
+    Permissive,
+    StringSource,
+    check,
+    executor,
+    multiple_process_executor_requirements,
+)
+from dagster.core.execution.retries import RetryMode, get_retries_config
 from dagster.grpc.types import ExecuteStepArgs
 from dagster.serdes import pack_value
 
@@ -35,7 +43,11 @@ CELERY_CONFIG = {
 }
 
 
-@executor(name="celery", config_schema=CELERY_CONFIG)
+@executor(
+    name="celery",
+    config_schema=CELERY_CONFIG,
+    requirements=multiple_process_executor_requirements(),
+)
 def celery_executor(init_context):
     """Celery-based executor.
 
@@ -51,20 +63,18 @@ def celery_executor(init_context):
     In the most common case, you may want to modify the ``broker`` and ``backend`` (e.g., to use
     Redis instead of RabbitMQ). We expect that ``config_source`` will be less frequently
     modified, but that when solid executions are especially fast or slow, or when there are
-    different requirements around idempotence or retry, it may make sense to execute pipelines
+    different requirements around idempotence or retry, it may make sense to execute jobs
     with variations on these settings.
 
-    If you'd like to configure a celery executor in addition to the
-    :py:class:`~dagster.default_executors`, you should add it to the ``executor_defs`` defined on a
-    :py:class:`~dagster.ModeDefinition` as follows:
+    To use the `celery_executor`, set it as the `executor_def` when defining a job:
 
     .. code-block:: python
 
-        from dagster import ModeDefinition, default_executors, pipeline
+        from dagster import job
         from dagster_celery import celery_executor
 
-        @pipeline(mode_defs=[ModeDefinition(executor_defs=default_executors + [celery_executor])])
-        def celery_enabled_pipeline():
+        @job(executor_def=celery_executor)
+        def celery_enabled_job():
             pass
 
     Then you can configure the executor as follows:
@@ -72,46 +82,45 @@ def celery_executor(init_context):
     .. code-block:: YAML
 
         execution:
-          celery:
-            config:
-              broker: 'pyamqp://guest@localhost//'  # Optional[str]: The URL of the Celery broker
-              backend: 'rpc://' # Optional[str]: The URL of the Celery results backend
-              include: ['my_module'] # Optional[List[str]]: Modules every worker should import
-              config_source: # Dict[str, Any]: Any additional parameters to pass to the
-                  #...       # Celery workers. This dict will be passed as the `config_source`
-                  #...       # argument of celery.Celery().
+          config:
+            broker: 'pyamqp://guest@localhost//'  # Optional[str]: The URL of the Celery broker
+            backend: 'rpc://' # Optional[str]: The URL of the Celery results backend
+            include: ['my_module'] # Optional[List[str]]: Modules every worker should import
+            config_source: # Dict[str, Any]: Any additional parameters to pass to the
+                #...       # Celery workers. This dict will be passed as the `config_source`
+                #...       # argument of celery.Celery().
 
     Note that the YAML you provide here must align with the configuration with which the Celery
     workers on which you hope to run were started. If, for example, you point the executor at a
     different broker than the one your workers are listening to, the workers will never be able to
     pick up tasks for execution.
     """
-    check_cross_process_constraints(init_context)
 
     return CeleryExecutor(
         broker=init_context.executor_config.get("broker"),
         backend=init_context.executor_config.get("backend"),
         config_source=init_context.executor_config.get("config_source"),
         include=init_context.executor_config.get("include"),
-        retries=Retries.from_config(init_context.executor_config["retries"]),
+        retries=RetryMode.from_config(init_context.executor_config["retries"]),
     )
 
 
-def _submit_task(app, pipeline_context, step, queue, priority):
+def _submit_task(app, plan_context, step, queue, priority, known_state):
     from .tasks import create_task
 
     execute_step_args = ExecuteStepArgs(
-        pipeline_origin=pipeline_context.pipeline.get_python_origin(),
-        pipeline_run_id=pipeline_context.pipeline_run.run_id,
+        pipeline_origin=plan_context.reconstructable_pipeline.get_python_origin(),
+        pipeline_run_id=plan_context.pipeline_run.run_id,
         step_keys_to_execute=[step.key],
-        instance_ref=pipeline_context.instance.get_ref(),
-        retries_dict=pipeline_context.executor.retries.for_inner_plan().to_config(),
+        instance_ref=plan_context.instance.get_ref(),
+        retry_mode=plan_context.executor.retries.for_inner_plan(),
+        known_state=known_state,
     )
 
     task = create_task(app)
     task_signature = task.si(
         execute_step_args_packed=pack_value(execute_step_args),
-        executable_dict=pipeline_context.pipeline.to_dict(),
+        executable_dict=plan_context.reconstructable_pipeline.to_dict(),
     )
     return task_signature.apply_async(
         priority=priority,
@@ -135,23 +144,23 @@ class CeleryExecutor(Executor):
         self.config_source = dict_wrapper(
             dict(DEFAULT_CONFIG, **check.opt_dict_param(config_source, "config_source"))
         )
-        self._retries = check.inst_param(retries, "retries", Retries)
+        self._retries = check.inst_param(retries, "retries", RetryMode)
 
     @property
     def retries(self):
         return self._retries
 
-    def execute(self, pipeline_context, execution_plan):
+    def execute(self, plan_context, execution_plan):
         from .core_execution_loop import core_celery_execution_loop
 
         return core_celery_execution_loop(
-            pipeline_context, execution_plan, step_execution_fn=_submit_task
+            plan_context, execution_plan, step_execution_fn=_submit_task
         )
 
     @staticmethod
     def for_cli(broker=None, backend=None, include=None, config_source=None):
         return CeleryExecutor(
-            retries=Retries(RetryMode.DISABLED),
+            retries=RetryMode(RetryMode.DISABLED),
             broker=broker,
             backend=backend,
             include=include,
